@@ -89,7 +89,7 @@ class DatabaseManager:
                 "default":{},
                 "test":{},
             },
-            "tables_instances":[],
+            "table_instances":[],
             "credentials":None,
         }
 
@@ -137,6 +137,9 @@ class DatabaseManager:
         if summary_path is not None:
             if _cfu.exists(summary_path):
                 self.master_summary_path = summary_path
+            else:
+                _log(f"Failed to locate summary file: {summary_path}","error")
+                return False
 
         indexing = _parse_master_summary_file(self)
         if indexing:
@@ -144,7 +147,7 @@ class DatabaseManager:
             self.gen_insert_data()
 
         if self.settings['auto_parse']:
-            # @Mstep [if]  compare the saved modified timestamp to the current timestamp.
+            # @Mstep [if] compare the saved modified timestamp to the current timestamp.
             if _has_master_changed(self):
                 _log("Master SQL has been modified, initiating auto parsing.")
                 self.parse_master_sql(
@@ -155,6 +158,7 @@ class DatabaseManager:
                 )
             else:
                 _log("Master SQL has not been modified since last parse.")
+            # self.gen_creates()
 
         self.save_master_summary()
         # _cfu.writer.to_json("dbman_summary_load.delete.json",self.settings)
@@ -488,7 +492,7 @@ class DatabaseManager:
 
         data = {}
         t:_table_manager.TableManager
-        for t in self.data['tables_instances']:
+        for t in self.data['table_instances']:
             # @Mstep [] get the table's default insert data.
             default_data = t.default_insert_json
             # @Mstep [] assign the data to the master_data dictionary.
@@ -587,7 +591,8 @@ class DatabaseManager:
                     self.master_summary_path = _os.path.dirname(sql_path) + "\\" + self.settings['master_summary_file_name']
 
             _log("    Parsing the Master SQL content.")
-            self._raw_sql_parse_data = _csu.parse.sql.parse(sql_path)
+            if isinstance(sql_path,(str)):
+                self._raw_sql_parse_data = _csu.parse.sql.parse(sql_path)
 
         data = self._raw_sql_parse_data.copy()
         for t in data['tables']:
@@ -820,6 +825,34 @@ class DatabaseManager:
             if tb is not None:
                 tb.gen_test_reset()
 
+    def gen_creates(self):
+        '''
+            Generate the create sql files for all tables in the databse.
+
+            ----------
+
+            Arguments
+            -------------------------
+            `tables` {str|list}
+                The table name or list of table names to reset.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 06-02-2022 14:44:02
+            `memberOf`: DatabaseManager
+            `version`: 1.0
+            `method_name`: gen_test_reset
+            * @xxx [06-02-2022 14:45:14]: documentation for gen_test_reset
+        '''
+
+
+        tables = _lu.force_list(self.tables)
+        for table in tables:
+            tb = self.get_table(table)
+            if tb is not None:
+                tb.gen_create_sql()
+
     def purge_test_data(self):
         '''
             Delete test data for all tables.
@@ -840,7 +873,7 @@ class DatabaseManager:
 
 
         tb:_table_manager.TableManager
-        for tb in self.data['tables_instances']:
+        for tb in self.data['table_instances']:
             tb.delete_test_data()
 
     def purge_tables(self):
@@ -876,7 +909,7 @@ class DatabaseManager:
             self._raw_sql_parse_data = _csu.parse.sql.parse(self.master_sql_path)
         purge = []
 
-        for tb in self.data['tables_instances']:
+        for tb in self.data['table_instances']:
             match_found = False
             for pt in self._raw_sql_parse_data['tables']:
                 if pt['table_name'] == tb.name:
@@ -908,7 +941,8 @@ class DatabaseManager:
 
     @property
     def table_instances(self)->_Iterable[_table_manager.TableManager]:
-        return self.data['tables_instances']
+        return self.data['table_instances']
+
     @property
     def tables(self)->_Iterable[dict]:
         '''
@@ -1093,7 +1127,7 @@ class DatabaseManager:
         # @Mstep [] update the tables data dictionary by gathering the summary from all tables.
         tables = []
         t:_table_manager.TableManager
-        for t in self.data['tables_instances']:
+        for t in self.data['table_instances']:
             summary =t.table_summary
             tables.append(summary)
         self.data['tables'] = tables
@@ -1346,7 +1380,7 @@ class DatabaseManager:
         '''
 
         t:_table_manager.TableManager
-        for t in self.data['tables_instances']:
+        for t in self.data['table_instances']:
             t.save_insert_data(gen_insert_sql)
             self.save_master_summary()
 
@@ -1768,8 +1802,6 @@ def database_from_sql(sql_path:str,**kwargs)->_Union[DatabaseManager,bool]:
     # @Mstep [RETURN] return the databaseManager instance.
     return db
 
-
-
 def database_from_summary(summary_path:str,**kwargs)->_Union[DatabaseManager,bool]:
     '''
         Instantiate a new Database Manager by loading it from a summary file.
@@ -1858,6 +1890,7 @@ def database_from_summary(summary_path:str,**kwargs)->_Union[DatabaseManager,boo
         db.credentials = credentials
     # @Mstep [] initiate the parsing of the master SQL file.
     db.load_from_summary()
+    
     # @Mstep [RETURN] return the databaseManager instance.
     return db
 
@@ -1942,7 +1975,7 @@ def _get_tables_by_schema(main:DatabaseManager,schema:_Union[str,list])->_Union[
     for s_name in schema:
         for s in main.data['schemas']:
             if s['name'] == s_name:
-                for t in main.data['tables_instances']:
+                for t in main.data['table_instances']:
                     if t['schema_name'] == s['name']:
                         tables.append(t)
     return tables
@@ -1955,7 +1988,7 @@ def _get_table_by_name(main:DatabaseManager,table_names:str,schema:str=None)->_t
         table_name = _csu.to_snake_case(table_name)
         tables = []
         t:_table_manager.TableManager
-        for t in main.data['tables_instances']:
+        for t in main.data['table_instances']:
             if schema is not None:
                 if t['schema_name'] == schema:
                     if t.table_name == table_name:
@@ -1965,22 +1998,32 @@ def _get_table_by_name(main:DatabaseManager,table_names:str,schema:str=None)->_t
                 # tables.append(t)
                 return t
     return None
-    # table_names = _lu.force_list(table_names)
-    # for table_name in table_names:
 
-    #     table_name = _csu.to_snake_case(table_name)
-    #     tables = []
-    #     t:_table_manager.TableManager
-    #     for t in main.data['tables_instances']:
-    #         if schema is not None:
-    #             if t['schema_name'] == schema:
-    #                 if t.table_name == table_name:
-    #                     tables.append(t)
-    #                     # return t
-    #         if t.table_name == table_name:
-    #             tables.append(t)
-    #             # return t
-    # return tables
+def _remove_table_instance(main:DatabaseManager,table_names:str,schema:str=None)->None:
+    if len(main.data['table_instances']) == 0:
+        return
+    
+    table_names = _lu.force_list(table_names)
+    tb_instances = []
+    for table_name in table_names:
+        table_name = _csu.to_snake_case(table_name)
+        t:_table_manager.TableManager
+        for t in main.data['table_instances']:
+            if schema is not None:
+                if t['schema_name'] == schema:
+                    if t.table_name != table_name:
+                        tb_instances.append(t)
+                        # return t
+            if t.table_name != table_name:
+                tb_instances.append(t)
+
+    main.data['table_instances'] = tb_instances
+
+def _set_table_instance(main:DatabaseManager,table_data:dict)->_table_manager.TableManager:
+    _remove_table_instance(main,table_data['table_name'])
+    tb = _table_manager.TableManager(main,table_data['table_name'],table_data['schema_name'],summary=table_data)
+    main.data['table_instances'].append(tb)
+    return tb
 
 def _generate_schema_dirs(main:DatabaseManager,schemas:_Iterable[dict])->_Iterable[dict]:
     '''
@@ -2069,7 +2112,9 @@ def _generate_table_files(main:DatabaseManager,tables:_Iterable[dict])->_Iterabl
         t['db_path'] = db_path
         t['has_test_files'] = False
 
-        tb = _table_manager.TableManager(main,table_name,schema_name,summary=t)
+        # tb = _table_manager.TableManager(main,table_name,schema_name,summary=t)
+        tb = _set_table_instance(main,t)
+        
         new_tables.append(tb.table_summary)
     return new_tables
 
@@ -2321,7 +2366,8 @@ def _parse_master_summary_file(main:DatabaseManager):
 
     longest_schema_name = 0
     schemas = []
-    tables = []
+    # tables = []
+    # @Mstep [LOOP] iterate the schema dictionaries
     for schema in master['schemas']:
         if len(schema['name']) > longest_schema_name:
             longest_schema_name = len(schema['name'])
@@ -2329,7 +2375,6 @@ def _parse_master_summary_file(main:DatabaseManager):
         schemas.append(schema)
         # @Mstep [LOOP] iterate the table data dictionaries
         for tb in schema['tables']:
-            # tb['default_insert_data'] = main.data['insert_data']['default'][tb['name']]
             # @Mstep [] add the default data to the to the dictionary.
             tb['default_insert_data'] = _obj.get_arg(
                 main.data['insert_data']['default'],
@@ -2345,11 +2390,13 @@ def _parse_master_summary_file(main:DatabaseManager):
                 (list))
 
             # @Mstep [] instantiate a tablemanager and append it to the tables list.
-            tables.append(_table_manager.TableManager(main,tb['name'],None,summary_path=tb))
+            _set_table_instance(main,tb)
+            # tables.append(_table_manager.TableManager(main,tb['name'],None,summary_path=tb))
 
     main.data['schemas'] = schemas
     main.data['longest_schema_name'] = longest_schema_name
-    main.data['tables_instances'] = tables
+    # main.data['table_instances'] = tables
+    main.save_master_summary()
     # main.data['tables'] = tables
     return True
 
@@ -2434,7 +2481,7 @@ def _parse_master_summary_file(main:DatabaseManager):
 
 #         table_name = _csu.to_snake_case(table_name)
 #         t:_table_manager.TableManager
-#         for t in main.data['tables_instances']:
+#         for t in main.data['table_instances']:
 #             if schema is not None:
 #                 if t['schema_name'] == schema:
 #                     if t.table_name != table_name:
@@ -2452,5 +2499,5 @@ def _parse_master_summary_file(main:DatabaseManager):
 #                 # print(_Fore.RED + f"Deleting {t.name}" + _Style.RESET_ALL)
 #                 # print(f"Deleting table instance: {table_name}")
 #                 match_found = True
-#     main.data['tables_instances'] = new_tables
+#     main.data['table_instances'] = new_tables
 #     return match_found
