@@ -24,6 +24,7 @@ import os as _os
 import urllib.parse
 
 import utils.dict_utils as _obj
+import utils.console_utils as _con
 # from pyparsing import And, Suppress,Dict, Word, Literal, Group, Optional, ZeroOrMore, OneOrMore, Regex, restOfLine, alphanums,nums, printables, string, CaselessKeyword,nestedExpr,ParseException,quotedString,removeQuotes,originalTextFor,delimitedList,QuotedString
 # from pyparsing import QuotedString
 
@@ -857,10 +858,10 @@ def dict_replace_string(value:str,replace:dict):
         -------------------------
         `value` {string}
             The string to replace values in.
-            
+
         `replace` {dict}
             The dictionary to use for replacements.
-            
+
             "find":"replace"
 
 
@@ -880,10 +881,10 @@ def dict_replace_string(value:str,replace:dict):
 
 
     if isinstance(replace,(dict)) is False:
-        print(f"The replace argument must be a dictionary")
+        _con.log("The replace argument must be a dictionary","error")
         return None
     
-    for k,v in replace:
+    for k,v in replace.items():
         if v is not None:
             value = value.replace(k,v)
     return value
